@@ -834,14 +834,14 @@ impl Expr {
     pub fn like(self, v: &str) -> SimpleExpr {
         self.bin_oper(
             BinOper::Like,
-            SimpleExpr::Value(Value::String(Box::new(v.to_owned()))),
+            SimpleExpr::Value(Value::String(Some(Box::new(v.to_owned())))),
         )
     }
 
     pub fn not_like(self, v: &str) -> SimpleExpr {
         self.bin_oper(
             BinOper::NotLike,
-            SimpleExpr::Value(Value::String(Box::new(v.to_owned()))),
+            SimpleExpr::Value(Value::String(Some(Box::new(v.to_owned())))),
         )
     }
 
@@ -1373,32 +1373,6 @@ impl Expr {
         self.bin_oper(BinOper::Contained, expr.into())
     }
 
-    /// Express an postgres concatenate (`||`) expression.
-    ///
-    /// # Examples
-    ///
-    /// ```
-    /// use sea_query::{*, tests_cfg::*};
-    ///
-    /// let query = Query::select()
-    ///     .columns(vec![Font::Name, Font::Variant, Font::Language])
-    ///     .from(Font::Table)
-    ///     .and_where(Expr::val("a").concatenate(Expr::val("b")))
-    ///     .to_owned();
-    ///
-    /// assert_eq!(
-    ///     query.to_string(PostgresQueryBuilder),
-    ///     r#"SELECT "name", "variant", "language" FROM "font" WHERE 'a' || 'b'"#
-    /// );
-    /// ```
-    #[cfg(feature = "backend-postgres")]
-    pub fn concatenate<T>(self, expr: T) -> SimpleExpr
-    where
-        T: Into<SimpleExpr>,
-    {
-        self.bin_oper(BinOper::Concatenate, expr.into())
-    }
-
     pub(crate) fn func(func: Function) -> Self {
         let mut expr = Expr::new();
         expr.func = Some(func);
